# flake8: noqa

# import apis into api package
from ZSGF.Client.api.access_token_api import AccessTokenApi
from ZSGF.Client.api.alipay_api import AlipayApi
from ZSGF.Client.api.app_api import AppApi
from ZSGF.Client.api.ding_talk_api import DingTalkApi
from ZSGF.Client.api.external_account_api import ExternalAccountApi
from ZSGF.Client.api.file_api import FileApi
from ZSGF.Client.api.o_auth_api import OAuthApi
from ZSGF.Client.api.order_api import OrderApi
from ZSGF.Client.api.storage_api import StorageApi
from ZSGF.Client.api.user_api import UserApi
from ZSGF.Client.api.user_currency_api import UserCurrencyApi
from ZSGF.Client.api.user_friends_api import UserFriendsApi
from ZSGF.Client.api.user_location_api import UserLocationApi
from ZSGF.Client.api.wechat_api import WechatApi

