# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class UserLogins(BaseModel):
    """
    用户外部账号
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="唯一标识符")
    user_id: Optional[StrictInt] = Field(default=None, description="关联的用户ID", alias="userID")
    platform_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="第三方平台名称", alias="platformName")
    platform: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="第三方平台")
    union_id: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="第三方平台唯一标识", alias="unionID")
    avatar: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="用户头像")
    data: Optional[StrictStr] = Field(default=None, description="扩展数据")
    enable: Optional[StrictBool] = Field(default=None, description="启用")
    create_date: Optional[datetime] = Field(default=None, description="创建时间", alias="createDate")
    last_update: Optional[datetime] = Field(default=None, description="最后更新时间", alias="lastUpdate")
    __properties: ClassVar[List[str]] = ["id", "userID", "platformName", "platform", "unionID", "avatar", "data", "enable", "createDate", "lastUpdate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserLogins from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if platform_name (nullable) is None
        # and model_fields_set contains the field
        if self.platform_name is None and "platform_name" in self.model_fields_set:
            _dict['platformName'] = None

        # set to None if platform (nullable) is None
        # and model_fields_set contains the field
        if self.platform is None and "platform" in self.model_fields_set:
            _dict['platform'] = None

        # set to None if union_id (nullable) is None
        # and model_fields_set contains the field
        if self.union_id is None and "union_id" in self.model_fields_set:
            _dict['unionID'] = None

        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserLogins from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "userID": obj.get("userID"),
            "platformName": obj.get("platformName"),
            "platform": obj.get("platform"),
            "unionID": obj.get("unionID"),
            "avatar": obj.get("avatar"),
            "data": obj.get("data"),
            "enable": obj.get("enable"),
            "createDate": obj.get("createDate"),
            "lastUpdate": obj.get("lastUpdate")
        })
        return _obj


