# coding: utf-8

# flake8: noqa

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.0.0"

# import apis into sdk package
from ZSGF.Client.api.access_token_api import AccessTokenApi
from ZSGF.Client.api.alipay_api import AlipayApi
from ZSGF.Client.api.app_api import AppApi
from ZSGF.Client.api.ding_talk_api import DingTalkApi
from ZSGF.Client.api.external_account_api import ExternalAccountApi
from ZSGF.Client.api.file_api import FileApi
from ZSGF.Client.api.o_auth_api import OAuthApi
from ZSGF.Client.api.order_api import OrderApi
from ZSGF.Client.api.storage_api import StorageApi
from ZSGF.Client.api.user_api import UserApi
from ZSGF.Client.api.user_currency_api import UserCurrencyApi
from ZSGF.Client.api.user_friends_api import UserFriendsApi
from ZSGF.Client.api.user_location_api import UserLocationApi
from ZSGF.Client.api.wechat_api import WechatApi

# import ApiClient
from ZSGF.Client.api_response import ApiResponse
from ZSGF.Client.api_client import ApiClient
from ZSGF.Client.configuration import Configuration
from ZSGF.Client.exceptions import OpenApiException
from ZSGF.Client.exceptions import ApiTypeError
from ZSGF.Client.exceptions import ApiValueError
from ZSGF.Client.exceptions import ApiKeyError
from ZSGF.Client.exceptions import ApiAttributeError
from ZSGF.Client.exceptions import ApiException

# import models into sdk package
from ZSGF.Client.models.access_token_list_result import AccessTokenListResult
from ZSGF.Client.models.access_token_list_result_api_response import AccessTokenListResultApiResponse
from ZSGF.Client.models.access_token_post_request import AccessTokenPostRequest
from ZSGF.Client.models.access_token_put_request import AccessTokenPutRequest
from ZSGF.Client.models.alipay_create_order_page_pay_request import AlipayCreateOrderPagePayRequest
from ZSGF.Client.models.alipay_create_order_request import AlipayCreateOrderRequest
from ZSGF.Client.models.alipay_create_order_wap_pay_request import AlipayCreateOrderWapPayRequest
from ZSGF.Client.models.alipay_trade_query_response import AlipayTradeQueryResponse
from ZSGF.Client.models.alipay_trade_query_response_api_response import AlipayTradeQueryResponseApiResponse
from ZSGF.Client.models.alipay_trade_refund_response import AlipayTradeRefundResponse
from ZSGF.Client.models.alipay_trade_refund_response_api_response import AlipayTradeRefundResponseApiResponse
from ZSGF.Client.models.app_info_item import AppInfoItem
from ZSGF.Client.models.app_info_result import AppInfoResult
from ZSGF.Client.models.app_info_result_api_response import AppInfoResultApiResponse
from ZSGF.Client.models.app_property import AppProperty
from ZSGF.Client.models.app_user_consent_model import AppUserConsentModel
from ZSGF.Client.models.app_user_consent_model_list_api_response import AppUserConsentModelListApiResponse
from ZSGF.Client.models.app_user_reset_email_request import AppUserResetEmailRequest
from ZSGF.Client.models.app_user_reset_phone_request import AppUserResetPhoneRequest
from ZSGF.Client.models.app_user_reset_pwd_request import AppUserResetPwdRequest
from ZSGF.Client.models.authorize_result import AuthorizeResult
from ZSGF.Client.models.authorize_result_api_response import AuthorizeResultApiResponse
from ZSGF.Client.models.bk_agent_resp_info import BkAgentRespInfo
from ZSGF.Client.models.boolean_api_response import BooleanApiResponse
from ZSGF.Client.models.charge_info import ChargeInfo
from ZSGF.Client.models.common_friend_model import CommonFriendModel
from ZSGF.Client.models.contribute_detail import ContributeDetail
from ZSGF.Client.models.create_order_request import CreateOrderRequest
from ZSGF.Client.models.create_order_result import CreateOrderResult
from ZSGF.Client.models.create_order_result_api_response import CreateOrderResultApiResponse
from ZSGF.Client.models.currency_consume_request import CurrencyConsumeRequest
from ZSGF.Client.models.currency_transaction import CurrencyTransaction
from ZSGF.Client.models.directory_item import DirectoryItem
from ZSGF.Client.models.email_sign_in_request import EmailSignInRequest
from ZSGF.Client.models.email_sign_up_request import EmailSignUpRequest
from ZSGF.Client.models.enterprise_pay_info import EnterprisePayInfo
from ZSGF.Client.models.exchange_currency_request import ExchangeCurrencyRequest
from ZSGF.Client.models.external_account_bind_request import ExternalAccountBindRequest
from ZSGF.Client.models.external_account_put_request import ExternalAccountPutRequest
from ZSGF.Client.models.external_account_sign_in_request import ExternalAccountSignInRequest
from ZSGF.Client.models.file_item import FileItem
from ZSGF.Client.models.file_list_result import FileListResult
from ZSGF.Client.models.file_list_result_api_response import FileListResultApiResponse
from ZSGF.Client.models.follower_model import FollowerModel
from ZSGF.Client.models.follower_put_model import FollowerPutModel
from ZSGF.Client.models.fulfillment_detail import FulfillmentDetail
from ZSGF.Client.models.geo_location import GeoLocation
from ZSGF.Client.models.geo_location_model import GeoLocationModel
from ZSGF.Client.models.geo_location_model_api_response import GeoLocationModelApiResponse
from ZSGF.Client.models.geo_location_response_model import GeoLocationResponseModel
from ZSGF.Client.models.get_user_profile_result import GetUserProfileResult
from ZSGF.Client.models.get_user_profile_result_api_response import GetUserProfileResultApiResponse
from ZSGF.Client.models.goods_detail import GoodsDetail
from ZSGF.Client.models.grant_request import GrantRequest
from ZSGF.Client.models.grant_result import GrantResult
from ZSGF.Client.models.grant_result_api_response import GrantResultApiResponse
from ZSGF.Client.models.hb_fq_pay_info import HbFqPayInfo
from ZSGF.Client.models.int64_api_response import Int64ApiResponse
from ZSGF.Client.models.intact_charge_info import IntactChargeInfo
from ZSGF.Client.models.my_sql_geometry import MySqlGeometry
from ZSGF.Client.models.object_api_response import ObjectApiResponse
from ZSGF.Client.models.object_list_api_response import ObjectListApiResponse
from ZSGF.Client.models.order import Order
from ZSGF.Client.models.order_api_response import OrderApiResponse
from ZSGF.Client.models.order_list_result import OrderListResult
from ZSGF.Client.models.order_list_result_api_response import OrderListResultApiResponse
from ZSGF.Client.models.payment_info_with_id import PaymentInfoWithId
from ZSGF.Client.models.phone_sign_in_request import PhoneSignInRequest
from ZSGF.Client.models.phone_sign_up_request import PhoneSignUpRequest
from ZSGF.Client.models.preset_pay_tool_info import PresetPayToolInfo
from ZSGF.Client.models.profile_result import ProfileResult
from ZSGF.Client.models.profile_result_api_response import ProfileResultApiResponse
from ZSGF.Client.models.qr_code_pre_sign_in_request import QRCodePreSignInRequest
from ZSGF.Client.models.qr_code_scan_request import QRCodeScanRequest
from ZSGF.Client.models.qr_code_sign_in_request import QRCodeSignInRequest
from ZSGF.Client.models.qr_code_sign_up_request import QRCodeSignUpRequest
from ZSGF.Client.models.recharge_point_request import RechargePointRequest
from ZSGF.Client.models.recommend_friend import RecommendFriend
from ZSGF.Client.models.refund_charge_info import RefundChargeInfo
from ZSGF.Client.models.refund_sub_fee import RefundSubFee
from ZSGF.Client.models.return_page_notify_request import ReturnPageNotifyRequest
from ZSGF.Client.models.send_email_code_request import SendEmailCodeRequest
from ZSGF.Client.models.send_sms_code_request import SendSMSCodeRequest
from ZSGF.Client.models.setup_code import SetupCode
from ZSGF.Client.models.setup_code_api_response import SetupCodeApiResponse
from ZSGF.Client.models.sign_in_request import SignInRequest
from ZSGF.Client.models.sign_up_request import SignUpRequest
from ZSGF.Client.models.storage_list_result import StorageListResult
from ZSGF.Client.models.storage_list_result_api_response import StorageListResultApiResponse
from ZSGF.Client.models.string_api_response import StringApiResponse
from ZSGF.Client.models.sub_fee import SubFee
from ZSGF.Client.models.tap_pay_info import TapPayInfo
from ZSGF.Client.models.token_model import TokenModel
from ZSGF.Client.models.token_model_api_response import TokenModelApiResponse
from ZSGF.Client.models.trade_fund_bill import TradeFundBill
from ZSGF.Client.models.trade_settle_detail import TradeSettleDetail
from ZSGF.Client.models.trade_settle_info import TradeSettleInfo
from ZSGF.Client.models.union_id_sign_in_request import UnionIDSignInRequest
from ZSGF.Client.models.union_id_sign_up_request import UnionIDSignUpRequest
from ZSGF.Client.models.update_profile_request import UpdateProfileRequest
from ZSGF.Client.models.user import User
from ZSGF.Client.models.user_access_token import UserAccessToken
from ZSGF.Client.models.user_common_interests_result import UserCommonInterestsResult
from ZSGF.Client.models.user_common_interests_result_api_response import UserCommonInterestsResultApiResponse
from ZSGF.Client.models.user_currency import UserCurrency
from ZSGF.Client.models.user_currency_currency_trans_result import UserCurrencyCurrencyTransResult
from ZSGF.Client.models.user_currency_currency_trans_result_api_response import UserCurrencyCurrencyTransResultApiResponse
from ZSGF.Client.models.user_currency_list_api_response import UserCurrencyListApiResponse
from ZSGF.Client.models.user_followers_result import UserFollowersResult
from ZSGF.Client.models.user_followers_result_api_response import UserFollowersResultApiResponse
from ZSGF.Client.models.user_friends_near_by_result import UserFriendsNearByResult
from ZSGF.Client.models.user_friends_near_by_result_api_response import UserFriendsNearByResultApiResponse
from ZSGF.Client.models.user_location_post_result import UserLocationPostResult
from ZSGF.Client.models.user_location_post_result_api_response import UserLocationPostResultApiResponse
from ZSGF.Client.models.user_locations_result import UserLocationsResult
from ZSGF.Client.models.user_locations_result_api_response import UserLocationsResultApiResponse
from ZSGF.Client.models.user_logins import UserLogins
from ZSGF.Client.models.user_logins_list_api_response import UserLoginsListApiResponse
from ZSGF.Client.models.user_mutual_followers_result import UserMutualFollowersResult
from ZSGF.Client.models.user_mutual_followers_result_api_response import UserMutualFollowersResultApiResponse
from ZSGF.Client.models.user_mutual_followings_result import UserMutualFollowingsResult
from ZSGF.Client.models.user_mutual_followings_result_api_response import UserMutualFollowingsResultApiResponse
from ZSGF.Client.models.user_profile_result import UserProfileResult
from ZSGF.Client.models.user_profile_result_api_response import UserProfileResultApiResponse
from ZSGF.Client.models.user_qr_code_scan_result import UserQRCodeScanResult
from ZSGF.Client.models.user_qr_code_scan_result_api_response import UserQRCodeScanResultApiResponse
from ZSGF.Client.models.voucher_detail import VoucherDetail
from ZSGF.Client.models.wechat_js_config_result import WechatJSConfigResult
from ZSGF.Client.models.wechat_js_config_result_api_response import WechatJSConfigResultApiResponse
